@@ -1,22 +1,9 @@
-# Copyright (C) 2014-2022 Greenbone AG
+# -*- coding: utf-8 -*-
+# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import logging
-import os
 import sys
 from pathlib import Path
 from typing import Callable, Dict, Optional
@@ -48,17 +35,6 @@ from .utils import (
 
 logger = logging.getLogger(__name__)
 
-SENTRY_DSN_NOTUS_SCANNER = os.environ.get("SENTRY_DSN_NOTUS_SCANNER")
-if SENTRY_DSN_NOTUS_SCANNER:
-    import sentry_sdk  # pylint: disable=import-error
-
-    sentry_sdk.init(  # pylint: disable=abstract-class-instantiated
-        SENTRY_DSN_NOTUS_SCANNER,
-        traces_sample_rate=1.0,
-        server_name=os.environ.get("SENTRY_SERVER_NAME"),
-        environment=os.environ.get("SENTRY_ENVIRONMENT"),
-    )
-
 
 def hashsum_verificator(
     products_directory_path: Path, disable: bool
