@@ -1,19 +1,7 @@
-# Copyright (C) 2021-2022 Greenbone AG
+# -*- coding: utf-8 -*-
+# SPDX-FileCopyrightText: 2021-2023 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import logging
 import re
@@ -186,7 +174,10 @@ class PackageAdvisories:
     )
 
     is_comparable = (
-        lambda a, b: a.compare(b) != PackageComparison.NOT_COMPARABLE
+        lambda a, b: a.compare(  # pylint: disable=unnecessary-lambda-assignment
+            b
+        )
+        != PackageComparison.NOT_COMPARABLE
     )
 
     comparison_map = {
@@ -221,7 +212,9 @@ class PackageAdvisories:
         if verifier not in self.comparison_map:
             verifier = ">="
         advisories = self.get_package_advisories_for_package(package)
-        is_vulnerable = lambda other: self.comparison_map[verifier](
+        is_vulnerable = lambda other: self.comparison_map[  # pylint: disable=unnecessary-lambda-assignment
+            verifier
+        ](
             package, other
         )
 
